"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.depsTask = void 0;

var _path = require("path");

var _toolLib = require("@kettil/tool-lib");

var _packageWorkspaces = require("../actions/npm/packageWorkspaces");

var _depcheck = require("../actions/tools/depcheck");

var _semver = require("../actions/tools/semver");

var _config = require("../cli/config");

var _spinner = require("../cli/spinner");

var _dependencyError = require("../errors/dependencyError");

var _taskHook = require("../utils/taskHook");

const depsTask = async argv => {
  const configIgnorePackages = await (0, _config.getConfig)(argv.root, 'deps.ignore.packages');
  const workspacePaths = await (0, _packageWorkspaces.npmPackageWorkspacesAction)(argv);
  const ignorePackages = (0, _toolLib.isArray)(configIgnorePackages) ? configIgnorePackages.filter(v => typeof v === 'string') : [];
  await (0, _taskHook.taskHook)(argv, {
    task: 'deps',
    type: 'pre'
  });

  try {
    await (0, _spinner.spinnerAction)((0, _depcheck.depcheckAction)(argv, {
      path: argv.root,
      ignorePackages
    }), 'Dependency verification');
    await workspacePaths.reduce((promise, workspacePath) => promise.then(() => (0, _spinner.spinnerAction)((0, _depcheck.depcheckAction)(argv, {
      path: workspacePath,
      ignorePackages
    }), `Dependency verification (workspace: ${(0, _path.basename)(workspacePath)})`)), Promise.resolve());
  } catch (error) {
    if (!(error instanceof _dependencyError.DependencyError)) {
      throw error;
    }

    argv.log.log(error.list);
  }

  await (0, _spinner.spinnerAction)((0, _semver.semverAction)(argv, {}), 'Semver check');
  await workspacePaths.reduce((promise, workspacePath) => promise.then(() => (0, _spinner.spinnerAction)((0, _semver.semverAction)(argv, {
    path: workspacePath
  }), `Semver check (workspace: ${(0, _path.basename)(workspacePath)})`)), Promise.resolve());
  await (0, _taskHook.taskHook)(argv, {
    task: 'deps',
    type: 'post'
  });
};

exports.depsTask = depsTask;